# Author: Acer Zhang
# Datetime: 2023/11/17
# Copyright belongs to the author.
# Please indicate the source for reprinting.

import os

from setuptools import setup
from setuptools import find_packages

setup(
    name='QPT_SDK',
    version='1.0',
    packages=find_packages(),
    url='https://github.com/GT-ZhangAcer/QPT',
    license='LGPL',
    author='GT-ZhangAcer',
    author_email='zhangacer@foxmail.com',
    description='QPT_SDK占位文件夹'
)
